# TFGrid3 Development Process

This document outlines our development process and how we prioritize feedback and feature requests for the TFGrid3 project.

## Milestone-Based Prioritization

We use a milestone-based approach to prioritize issues and feature requests in our Gitea repository. This helps us organize our development efforts and provides transparency to the community about what we're working on and what's coming next.

### Priority Categories

We categorize our work into the following priority levels:

#### Now

Issues marked with the "Now" milestone are our current top priorities. These are actively being worked on and will be included in the next release. We focus our immediate development efforts on these items.

[View "Now" milestone issues](https://git.ourworld.tf/tfgrid/tfgrid3_feedback/milestone/34)

#### Next

The "Next" milestone contains issues that are planned for upcoming releases after the current development cycle. These are important features or fixes that have been prioritized but aren't in active development yet.

[View "Next" milestone issues](https://git.ourworld.tf/tfgrid/tfgrid3_feedback/milestone/35)

#### Later

Issues in the "Later" milestone are on our radar but are scheduled for future consideration. These may be features that require more planning, have dependencies on other work, or are simply lower priority at this time.

[View "Later" milestone issues](https://git.ourworld.tf/tfgrid/tfgrid3_feedback/milestone/36)

#### ToSort

The "ToSort" milestone contains issues that need to be collectively reviewed and categorized. These are items that require community input to determine their priority level. We encourage community members to participate in discussions about these issues to help us properly categorize them.

[View "ToSort" milestone issues](https://git.ourworld.tf/tfgrid/tfgrid3_feedback/milestone/37)

## How We Determine Priorities

Our prioritization process takes into account several factors:

1. Community feedback and requests
2. Strategic alignment with project goals
3. Technical dependencies and prerequisites
4. Available resources and development capacity

## Contributing to the Process

We welcome community input on our priorities. If you have feedback on what should be prioritized, please:

1. Comment on existing issues to express your interest or provide additional context
2. Open new issues for features or improvements not yet tracked
3. Participate in community discussions about roadmap and priorities

Your input helps us ensure we're focusing on what matters most to the TFGrid3 community.

## Issue Labels

We use a set of labels to categorize issues and provide additional context about their nature and urgency. Understanding these labels helps contributors identify the type of issues they might want to work on or provide feedback for.

### Label Types

#### Defect
Used for bugs, errors, or functionality that isn't working as expected. Defects require fixing to restore proper functionality.

#### Feedback
Applied to issues that contain community feedback, suggestions, or general input about existing features or the project as a whole.

#### Question
Marks issues that ask for clarification, information, or guidance about the project, its features, or processes.

#### Roadmap
Indicates issues that represent significant features or milestones on our development roadmap. These often involve multiple tasks and align with strategic goals.

#### Story
Represents user stories or feature requests that describe functionality from an end-user perspective. 

#### Task
Denotes specific, actionable work items that need to be completed. Tasks are often more granular than stories and may be part of implementing a larger story or roadmap item. Avoid putting many tasks, team should take responsibility to resolve stories.

#### Urgent
Highlights issues that require immediate attention due to their critical nature, such as security vulnerabilities or major functionality breakdowns.

### Using Labels

When creating or interacting with issues:

1. Consider which label(s) best describe the nature of the issue
2. Look for issues with labels that match your interests or expertise if you want to contribute
3. Respect the urgency indicated by labels, particularly for "Urgent" items
4. Understand that labels may change as issues evolve or are better understood

Labels work in conjunction with milestones to provide a comprehensive view of our project's status and priorities.

## Development Workflow

Once issues are prioritized, they follow this general workflow:

1. Specification and planning (documented in the `/specs` directory)
2. Implementation and testing
3. Review and feedback
4. Deployment and release
5. Post-release monitoring and iteration

This process helps ensure that we deliver high-quality features that meet the needs of our community.
